#
# spec file for package thunar-plugin-archive
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define plugin_name thunar-archive-plugin

Name:           thunar-plugin-archive
Version:        0.5.2
Release:        1.2
URL:            https://docs.xfce.org/xfce/thunar/archive
Source0:        https://archive.xfce.org/src/thunar-plugins/%{plugin_name}/0.5/%{plugin_name}-%{version}.tar.bz2
Summary:        Thunar Plugin Providing Integration with Archive Managers
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
BuildRequires:  intltool
BuildRequires:  pkgconfig(exo-2) >= 0.10.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(thunarx-3) >= 0.4.0
Requires:       thunar >= 1.7.0
Recommends:     %{name}-lang = %{version}
Provides:       %{plugin_name} = %{version}
Obsoletes:      %{plugin_name} < %{version}

%description
The Thunar Archive Plugin allows for creating and extracting archive files
through the file context menus in the Thunar file manager using an archive
manager. It provides scripting interface that can be used to adapt it to
different archive managers.

%lang_package

%prep
%setup -q -n %{plugin_name}-%{version}

%build
%configure --disable-static
%make_build

%install
%make_install

rm -rf %{buildroot}%{_libdir}/thunarx-3/thunar-archive-plugin.la

# remove unsupported locales
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{plugin_name} %{?no_lang_C}

%files
%defattr(-,root,root)
%{_libdir}/thunarx-3/thunar-archive-plugin.so
%{_libexecdir}/thunar-archive-plugin
%{_datadir}/icons/*/*/*/tap-*.png

%files lang -f %{plugin_name}.lang

%changelog
* Mon Oct 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.2
  * Add/fix support for bz2 and bz3 files (#20)
  * Add a few more compression mimetypes, sort the list.
* Sat Apr  1 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.1
  * Fix use-after-free crash in "tap_provider_child_watch_destroy"
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Use generic package icon name in dialog header
  * Translation Updates
* Tue May 10 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.0
  * Fix for ark (gxo#thunar-plugins/thunar-archive-plugin#g4)
  * automake: INCLUDES -> AM_CPPFLAGS
  * preserve callbacks in tap-provider
  * remove GSpawnChildSetupFunc usage from tap_backend_run
  * Adds new README.md
  * updates AM_INIT_AUTOMAKE macro with foreign option
  * Add basic GitLab pipeline
  * Allow zip files (i.e. odt, docx...) to be compressed
    (gxo#thunar-plugins/thunar-archive-plugin#g15295)
  * Start archive application from file's directory
    (gxo#thunar-plugins/thunar-archive-plugin#g14773)
  * Replace AC_PROG_LIBTOOL with IT_PROG_INTLTOOL
  * Add support for archive manager for MATE
  * Translation Updates
- Remove thunar-archive-plugin-0.3.0-fix-file-roller-extract-here.patch
* Fri Jun 15 2018 seife+obs@b1-systems.com
- update to version 0.4.0
  - GTK3 Port
  - Thunarx-3 Port (Thunar >=1.7.0 required)
  - Engrampa archiver is now supported
  - Updated translations
* Sun Nov 16 2014 gber@opensuse.org
- fix file-roller symlink name and target (boo#905666)
* Wed Apr 30 2014 gber@opensuse.org
- add compatibility symlink for the desktop file from file-roller
  >= 3.12
* Sat May 11 2013 gber@opensuse.org
- update to version 0.3.1
  - fix build with --as-needed
  - automake updates
  - fix unused but set variable
  - translation updates
* Tue Mar 27 2012 gber@opensuse.org
- added source URL
* Thu Mar 22 2012 gber@opensuse.org
- updated URL
- corrected summary
- updated build dependencies
- split off -lang subpackage
* Mon Oct 10 2011 gber@opensuse.org
- added
  thunar-archive-plugin-0.3.0-fix-file-roller-extract-here.patch in
  order to make file-roller really extract files to the current
  directory to match the behavior of xarchiver
* Sat Oct  8 2011 gber@opensuse.org
- do not depend on xarchiver, it can be used with different archive
  managers
* Thu Mar 10 2011 gber@opensuse.org
- new package (split off from thunar-plugins)
